from simpleicons.icon import Icon
gitter_icon= Icon(
    title="Gitter",
    slug="gitter",
    hex="ED1965",
    source="https://gitter.im/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Gitter</title><path d="M8.501 4.001H10.5V24H8.501V4.001zm6.999 0V24h-2V4.001h2zM3.5 0h2.001v15H3.5V0zm15 4.001h2V15h-2V4.001z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
angular_icon= Icon(
    title="Angular",
    slug="angular",
    hex="DD0031",
    source="https://angular.io/assets/images/logos/angular/angular_solidBlack.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Angular</title><path d="M9.931 12.645h4.138l-2.07-4.908m0-7.737L.68 3.982l1.726 14.771L12 24l9.596-5.242L23.32 3.984 11.999.001zm7.064 18.31h-2.638l-1.422-3.503H8.996l-1.422 3.504h-2.64L12 2.65z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
strava_icon= Icon(
    title="Strava",
    slug="strava",
    hex="FC4C02",
    source="https://itunes.apple.com/us/app/strava-running-and-cycling-gps/id426826309",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Strava</title><path d="M15.387 17.944l-2.089-4.116h-3.065L15.387 24l5.15-10.172h-3.066m-7.008-5.599l2.836 5.598h4.172L10.463 0l-7 13.828h4.169"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
abletonlive_icon= Icon(
    title="Ableton Live",
    slug="abletonlive",
    hex="000000",
    source="https://www.ableton.com/en/legal/branding-trademark-guidelines/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Ableton Live</title><path d="M0 6.4v11.2h1.6V6.4zm3.2 0v11.2h1.6V6.4zm3.2 0v11.2H8V6.4zm3.2 0v11.2h1.6V6.4zm3.2 0V8H24V6.4zm0 3.2v1.6H24V9.6zm0 3.2v1.6H24v-1.6zm0 3.2v1.6H24V16z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
oracle_icon= Icon(
    title="Oracle",
    slug="oracle",
    hex="F80000",
    source="https://www.oracle.com/opn/index.html",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Oracle</title><path d="M16.412 4.412h-8.82a7.588 7.588 0 0 0-.008 15.176h8.828a7.588 7.588 0 0 0 0-15.176zm-.193 12.502H7.786a4.915 4.915 0 0 1 0-9.828h8.433a4.914 4.914 0 1 1 0 9.828z"/></svg>""",
    guidelines='https://www.oracle.com/legal/logos.html',
    license=None,
)



from simpleicons.icon import Icon
marketo_icon= Icon(
    title="Marketo",
    slug="marketo",
    hex="5C4C9F",
    source="https://www.marketo.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Marketo</title><path d="M16.146 0v24l6.134-4.886V3.334zM13.293 18.758l-4.939 2.157V2.086l4.939 1.462zM1.721 18.205l3.78-.999V5.188l-3.762-.606z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
mcafee_icon= Icon(
    title="McAfee",
    slug="mcafee",
    hex="C01818",
    source="https://www.mcafee.com/enterprise/en-us/about/newsroom/product-images.html",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>McAfee</title><path d="M12 4.8233L1.5793 0v19.1767L12 24l10.4207-4.8233V0zm6.172 11.626l-6.143 2.8428-6.1438-2.8429V6.6894l6.1439 2.8418 6.1429-2.8418z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
okta_icon= Icon(
    title="Okta",
    slug="okta",
    hex="007DC1",
    source="https://www.okta.com/press-room/media-assets/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Okta</title><path d="M12 0C5.389 0 0 5.35 0 12s5.35 12 12 12 12-5.35 12-12S18.611 0 12 0zm0 18c-3.325 0-6-2.675-6-6s2.675-6 6-6 6 2.675 6 6-2.675 6-6 6z"/></svg>""",
    guidelines='https://www.okta.com/terms-of-use-for-okta-content/',
    license=None,
)



from simpleicons.icon import Icon
spreaker_icon= Icon(
    title="Spreaker",
    slug="spreaker",
    hex="F5C300",
    source="https://www.spreaker.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Spreaker</title><path d="M14.615 0l-5.64 6.54L.529 4.718l8.68 7.372-8.537 7.463 8.411-1.984L14.843 24l.71-8.601 7.918-3.483-7.963-3.33L14.621 0h-.006z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
verizon_icon= Icon(
    title="Verizon",
    slug="verizon",
    hex="CD040B",
    source="https://www.verizondigitalmedia.com/about/logo-usage/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Verizon</title><path d="M18.302 0H22v.003L10.674 24H7.662L2 12h3.727l3.449 7.337z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
alpinedotjs_icon= Icon(
    title="Alpine.js",
    slug="alpinedotjs",
    hex="8BC0D0",
    source="https://github.com/simple-icons/simple-icons/issues/5583#issuecomment-832770167",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Alpine.js</title><path d="m24 12-5.72 5.746-5.724-5.741 5.724-5.75L24 12zM5.72 6.254 0 12l5.72 5.746h11.44L5.72 6.254z"/></svg>""",
    guidelines=None,
    license=None,
)



from io import BytesIO
from typing import Tuple

from PIL import Image
from reportlab.graphics import renderPM
from svglib.svglib import svg2rlg


def icon_to_image(
    icon_xml: bytes, bg: int = 0xFFFFFF, scale: Tuple[int, int] = (1, 1)
) -> Image:
    """Convert icon to PIL image.

    Args:
        icon_xml: The XML for an icon as bytes.
        bg: The background color for the image. Defaults to 0xffffff.
        scale: A tuple of the two values for the scale of the image. Defaults to (1, 1).
    """

    drawing = svg2rlg(BytesIO(icon_xml))

    drawing.width *= scale[0]
    drawing.height *= scale[1]
    drawing.scale(*scale)

    img_io = BytesIO()
    renderPM.drawToFile(drawing, img_io, fmt="PNG", bg=bg)
    return Image.open(img_io)



from simpleicons.icon import Icon
naver_icon= Icon(
    title="Naver",
    slug="naver",
    hex="03C75A",
    source="https://www.navercorp.com/investment/annualReport",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Naver</title><path d="M1.6 0S0 0 0 1.6v20.8S0 24 1.6 24h20.8s1.6 0 1.6-1.6V1.6S24 0 22.4 0zm3.415 5.6h4.78l4.425 6.458V5.6h4.765v12.8h-4.78L9.78 11.943V18.4H5.015Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
macys_icon= Icon(
    title="Macy’s",
    slug="macys",
    hex="E21A2C",
    source="https://www.macysinc.com/news-media/media-assets",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Macy’s</title><path d="M12.015.624L9.19 9.293H0l7.445 5.384-2.819 8.673L12 17.986l7.422 5.393-2.835-8.713L24 9.292h-9.162L12.015.622v.002z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
artixlinux_icon= Icon(
    title="Artix Linux",
    slug="artixlinux",
    hex="10A0CC",
    source="https://gitea.artixlinux.org/artix/artwork/src/commit/256432e3d06b3e9024bfd6912768e80281ea3746/icons/logo-gray.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Artix Linux</title><path d="M12 0L7.873 8.462l11.358 6.363zM6.626 11.018L.295 24l18.788-7.762zm13.846 6.352l-5.926 3.402L23.706 24Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
letterboxd_icon= Icon(
    title="Letterboxd",
    slug="letterboxd",
    hex="00D735",
    source="https://letterboxd.com/about/logos/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Letterboxd</title><path d="M8.29 16.752V7.2H6.546V4.8h6.328v2.4h-1.746v9.574h3.925v-2.618h2.839V19.2H6.545v-2.448h1.746zM0 12c0 6.628 5.372 12 12 12s12-5.372 12-12S18.628 0 12 0 0 5.372 0 12z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
manjaro_icon= Icon(
    title="Manjaro",
    slug="manjaro",
    hex="35BF5C",
    source="https://manjaro.org/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Manjaro</title><path d="M0 0v24h6.75V6.75h8.625V0H0zm8.625 8.625V24h6.75V8.625h-6.75zM17.25 0v24H24V0h-6.75z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
transferwise_icon= Icon(
    title="TransferWise",
    slug="transferwise",
    hex="00B9FF",
    source="https://brand.transferwise.com/logo",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>TransferWise</title><path d="M9.871 24h3.11L23.127 0H3.694l3.748 6.291-6.571 6.283h11.361l1.068-2.517H7.03l3.792-3.783L8.61 2.516h10.337z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
micropython_icon= Icon(
    title="MicroPython",
    slug="micropython",
    hex="2B2728",
    source="https://commons.wikimedia.org/wiki/File:MicroPython_new_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>MicroPython</title><path d="M0 0h11.509v18.737h.982V0H24v24h-5.263V5.263h-.983V24H6.246V5.263l-.983.035V24H0zm22.246 19.509h-1.404v2.386h1.404z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
polymerproject_icon= Icon(
    title="Polymer Project",
    slug="polymerproject",
    hex="FF4470",
    source="https://github.com/Polymer/polymer-project.org/blob/3d3e967446858b49a7796676714865ac9b2a5275/app/images/logos/p-logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Polymer Project</title><path d="M14.4 3.686L7.2 16.16 4.8 12l4.8-8.314H4.8L0 12l2.4 4.159 2.4 4.155h4.8l7.2-12.469L19.2 12l-4.8 8.314h4.8l2.4-4.155L24 12l-2.4-4.155-2.4-4.159Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
flutter_icon= Icon(
    title="Flutter",
    slug="flutter",
    hex="02569B",
    source="https://flutter.dev/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Flutter</title><path d="M14.314 0L2.3 12 6 15.7 21.684.013h-7.357zm.014 11.072L7.857 17.53l6.47 6.47H21.7l-6.46-6.468 6.46-6.46h-7.37z"/></svg>""",
    guidelines='https://flutter.dev/brand',
    license=None,
)



from simpleicons.icon import Icon
shotcut_icon= Icon(
    title="Shotcut",
    slug="shotcut",
    hex="115C77",
    source="https://shotcut.com/media/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Shotcut</title><path d="M0 0h6.667v24H0v-.889h5.778V.889H0V0zm7.556 0v24H24v-.889H8.444V.889H24V0H7.556zm1.388 22.611H24V1.389H8.944v21.222zM5.278 1.389H0v21.222h5.278V1.389z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
shutterstock_icon= Icon(
    title="Shutterstock",
    slug="shutterstock",
    hex="EE2B24",
    source="https://www.shutterstock.com/press/media",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Shutterstock</title><path d="M9.839 18.761h5.313a1.53 1.53 0 0 0 1.527-1.528v-5.76h5.237v5.76A6.767 6.767 0 0 1 15.152 24H9.839v-5.239M14.16 5.237H8.85a1.53 1.53 0 0 0-1.53 1.527v5.761H2.085V6.764A6.763 6.763 0 0 1 8.85 0h5.31v5.237Z"/></svg>""",
    guidelines='https://www.shutterstock.com/press/media',
    license=None,
)



from simpleicons.icon import Icon
minutemailer_icon= Icon(
    title="Minutemailer",
    slug="minutemailer",
    hex="30B980",
    source="https://minutemailer.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Minutemailer</title><path d="M17.187 19.181L24 4.755 0 12.386l9.196 1.963.043 4.896 2.759-2.617-2.147-2.076 7.336 4.63z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
chartmogul_icon= Icon(
    title="ChartMogul",
    slug="chartmogul",
    hex="13324B",
    source="https://chartmogul.com/company/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>ChartMogul</title><path d="M10.621 19.89V8.75L2.867 19.89H0V4.11h2.758v11.112l7.754-11.113h2.867v11.14L21.16 4.11H24v15.782h-2.73V8.75l-7.755 11.14Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
substack_icon= Icon(
    title="Substack",
    slug="substack",
    hex="FF6719",
    source="https://on.substack.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Substack</title><path d="M22.539 8.242H1.46V5.406h21.08v2.836zM1.46 10.812V24L12 18.11 22.54 24V10.812H1.46zM22.54 0H1.46v2.836h21.08V0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
ycombinator_icon= Icon(
    title="Y Combinator",
    slug="ycombinator",
    hex="F0652F",
    source="https://www.ycombinator.com/press/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Y Combinator</title><path d="M0 24V0h24v24H0zM6.951 5.896l4.112 7.708v5.064h1.583v-4.972l4.148-7.799h-1.749l-2.457 4.875c-.372.745-.688 1.434-.688 1.434s-.297-.708-.651-1.434L8.831 5.896h-1.88z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
containerd_icon= Icon(
    title="containerd",
    slug="containerd",
    hex="575757",
    source="https://cncf-branding.netlify.app/projects/containerd/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>containerd</title><path d="M3.629 0v24H20.37V0zM17.59 21.208H6.421V10.604h7.812V6.692h3.346v14.516zm-7.823-7.812h4.466v5.02H9.767z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
futurelearn_icon= Icon(
    title="FutureLearn",
    slug="futurelearn",
    hex="DE00A5",
    source="https://www.futurelearn.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>FutureLearn</title><path d="M22.081.61v7.566h-7.223v6.661H7.566v6.634H0v1.92h9.471v-6.649h7.306v-6.66H24V.61Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
asciinema_icon= Icon(
    title="asciinema",
    slug="asciinema",
    hex="D40000",
    source="https://github.com/asciinema/asciinema-logo",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>asciinema</title><path d="M1.61 0V24L22.39 12L1.61 0M5.76 7.2L10.06 9.68L5.76 12.16V7.2M12.55 11.12L14.08 12L5.76 16.8V15.04L12.55 11.12Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
materialdesignicons_icon= Icon(
    title="Material Design Icons",
    slug="materialdesignicons",
    hex="2196F3",
    source="https://materialdesignicons.com/icon/vector-square",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Material Design Icons</title><path d="M0 0h7.2v2.4h9.6V0H24v7.2h-2.4v9.6H24V24h-7.2v-2.4H7.2V24H0v-7.2h2.4V7.2H0V0m16.8 7.2V4.8H7.2v2.4H4.8v9.6h2.4v2.4h9.6v-2.4h2.4V7.2M2.4 2.4v2.4h2.4V2.4m14.4 0v2.4h2.4V2.4M2.4 19.2v2.4h2.4v-2.4m14.4 0v2.4h2.4v-2.4z"/></svg>""",
    guidelines=None,
    license={'type': 'Apache-2.0', 'url': 'https://spdx.org/licenses/Apache-2.0'},
)



from simpleicons.icon import Icon
slashdot_icon= Icon(
    title="Slashdot",
    slug="slashdot",
    hex="026664",
    source="https://commons.wikimedia.org/wiki/File:Slashdot_wordmark_and_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Slashdot</title><path d="M19.777 0L7.037 24H1.868L14.605 0h5.172zm2.354 19.801c0 2.268-1.841 4.105-4.109 4.105s-4.107-1.838-4.107-4.105 1.839-4.107 4.107-4.107 4.109 1.839 4.109 4.107z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
accenture_icon= Icon(
    title="Accenture",
    slug="accenture",
    hex="A100FF",
    source="https://www.accenture.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Accenture</title><path d="M23.297 14.74L.434 24v-5.263L16.8 12.11l6.497 2.631zm.27-5.371L.433 0v5.263l23.132 9.368V9.37z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
bandsintown_icon= Icon(
    title="Bandsintown",
    slug="bandsintown",
    hex="00CEC8",
    source="https://corp.bandsintown.com/media-library",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bandsintown</title><path d="M18.783 0H24v12h-5.217V0zm-6.261 5h5.217v7h-5.217V5zM6.26 5h5.217v7H6.261V5zM24 24H0V0h5.217v19h13.566v-1H6.26v-5H24v11Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
pytorchlightning_icon= Icon(
    title="PyTorch Lightning",
    slug="pytorchlightning",
    hex="792EE5",
    source="https://github.com/PyTorchLightning/pytorch-lightning/blob/a584196abf820179adb0758ef67ddae91c44e7bc/docs/source/_static/images/icon.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>PyTorch Lightning</title><path d="M12 0L1.75 6v12L12 24l10.25-6V6zm-1.775 18l1.08-4.657-2.428-2.397L13.79 6l-1.082 4.665 2.414 2.384z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
platformdotsh_icon= Icon(
    title="Platform.sh",
    slug="platformdotsh",
    hex="1A182A",
    source="https://platform.sh/logos/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Platform.sh</title><path d="M24 0H0v9.541h24V0zM24 20.755H0V24h24v-3.245zM0 12.618h24v4.892H0v-4.892z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
androidauto_icon= Icon(
    title="Android Auto",
    slug="androidauto",
    hex="3DDC84",
    source="https://thepartnermarketinghub.withgoogle.com/brands/android-auto/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Android Auto</title><path d="M12 0c-.6 0-1.11.32-1.39.8L.48 18.4a1.6 1.6 0 0 0 1.39 2.4h2l7.7-13.58.43-.77 8.13 14.35h2a1.6 1.6 0 0 0 1.39-2.4L13.39.8A1.6 1.6 0 0 0 12 0zm0 7.47l-9.07 16 .54.53L12 20.8l8.53 3.2.54-.53z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
facebookgaming_icon= Icon(
    title="Facebook Gaming",
    slug="facebookgaming",
    hex="005FED",
    source="https://www.facebook.com/fbgaminghome/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Facebook Gaming</title><path d="M0 0v24h15.67v-7.35H7.35v-9.3H24V0zm8.33 15.68h8.32V24H24V8.32H8.33Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
trustpilot_icon= Icon(
    title="Trustpilot",
    slug="trustpilot",
    hex="00B67A",
    source="https://support.trustpilot.com/hc/en-us/articles/206289947-Trustpilot-Brand-Assets-Style-Guide",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Trustpilot</title><path d="M17.227 16.67l2.19 6.742-7.413-5.388 5.223-1.354zM24 9.31h-9.165L12.005.589l-2.84 8.723L0 9.3l7.422 5.397-2.84 8.714 7.422-5.388 4.583-3.326L24 9.311z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
kaufland_icon= Icon(
    title="Kaufland",
    slug="kaufland",
    hex="E10915",
    source="https://www.kaufland.com/etc.clientlibs/kaufland/clientlibs/clientlib-klsite/resources/frontend/img/kl-logo-small-e825b661c5.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Kaufland</title><path d="M0 24h24V0H0zm23.008-.989H.989V.989h22.022zM3.773 3.776h7.651v7.65H3.773zm8.801 0v7.652l7.653-7.652zm-8.801 8.8h7.651v7.651H3.773zm8.801-.004v7.652h7.653z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
pinboard_icon= Icon(
    title="Pinboard",
    slug="pinboard",
    hex="0000FF",
    source="https://commons.wikimedia.org/wiki/File:Feedbin-Icon-share-pinboard.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pinboard</title><path d="M13.352 14.585l-4.509 4.614.72-4.062L3.428 7.57 0 7.753 7.58 0v2.953l7.214 6.646 4.513-1.105-4.689 4.982L24 24l-10.648-9.415z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
pandora_icon= Icon(
    title="Pandora",
    slug="pandora",
    hex="224099",
    source="https://www.pandoraforbrands.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pandora</title><path d="M1.882 0v24H8.32a1.085 1.085 0 001.085-1.085v-4.61h1.612c7.88 0 11.103-4.442 11.103-9.636C22.119 2.257 17.247 0 12.662 0H1.882Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
flipboard_icon= Icon(
    title="Flipboard",
    slug="flipboard",
    hex="E12828",
    source="https://about.flipboard.com/brand-guidelines",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Flipboard</title><path d="M0 0v24h24V0H0zm19.2 9.6h-4.8v4.8H9.6v4.8H4.8V4.8h14.4v4.8z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
suckless_icon= Icon(
    title="suckless",
    slug="suckless",
    hex="1177AA",
    source="https://suckless.org",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>suckless</title><path d="M0 4h24v4H4v2h20v10H0v-4h20v-2H0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
istio_icon= Icon(
    title="Istio",
    slug="istio",
    hex="466BB0",
    source="https://github.com/istio/istio/blob/5a047251817eb2523af297607b7614120812e47a/logo/istio-bluelogo-whitebackground-unframed.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Istio</title><path d="M4 21 20 21 10 24zM4 20 10 19 10 8zM11 19 20 20 11 0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
googlehangouts_icon= Icon(
    title="Google Hangouts",
    slug="googlehangouts",
    hex="0C9D58",
    source="https://upload.wikimedia.org/wikipedia/commons/e/ee/Hangouts_icon.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Google Hangouts</title><path d="M12 0C6.2 0 1.5 4.7 1.5 10.5c0 5.5 5 10 10.5 10V24c6.35-3.1 10.5-8.2 10.5-13.5C22.5 4.7 17.8 0 12 0zm-.5 12c0 1.4-.9 2.5-2 2.5V12H7V7.5h4.5V12zm6 0c0 1.4-.9 2.5-2 2.5V12H13V7.5h4.5V12z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
awesomewm_icon= Icon(
    title="awesomeWM",
    slug="awesomewm",
    hex="535D6C",
    source="https://awesomewm.org/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>awesomeWM</title><path d="M0 24V8.25h16.5V7.5H0V0h24v24h-7.5v-8.25h-9v.75h8.25V24z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
dwm_icon= Icon(
    title="dwm",
    slug="dwm",
    hex="1177AA",
    source="https://dwm.suckless.org",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>dwm</title><path d="M0 11h6V7h2v8h2v-4h2v4h2v-4h10v6h-2v-4h-2v4h-2v-4h-2v4H2v-2h4v-2H2v4H0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
guangzhoumetro_icon= Icon(
    title="Guangzhou Metro",
    slug="guangzhoumetro",
    hex="C51935",
    source="https://commons.wikimedia.org/wiki/File:Guangzhou_Metro_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Guangzhou Metro</title><path d="M16.433 12.329A16.188 16.188 0 0 1 22.118.009L17.684 0a16.2 16.2 0 0 0-4.776 11.374V24h3.525zm-8.869 0A16.174 16.174 0 0 0 1.882.009L6.319 0a16.238 16.238 0 0 1 4.773 11.374V24H7.564z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
microstrategy_icon= Icon(
    title="MicroStrategy",
    slug="microstrategy",
    hex="D9232E",
    source="https://www.microstrategy.com/en/company/press-kit",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>MicroStrategy</title><path d="M9.095 2.572h5.827v18.856H9.096zM0 2.572h5.825v18.856H.001zm18.174 0v18.854H24V8.33z"/></svg>""",
    guidelines='https://www.microstrategy.com/en/company/press-kit',
    license=None,
)



from simpleicons.icon import Icon
purism_icon= Icon(
    title="Purism",
    slug="purism",
    hex="2D2D2D",
    source="https://puri.sm/pr/images/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Purism</title><path d="M24 19.588H0V4.412h24zM2.824 16.765h18.352v-9.53H2.824Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
vercel_icon= Icon(
    title="Vercel",
    slug="vercel",
    hex="000000",
    source="https://vercel.com/design",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vercel</title><path d="M24 22.525H0l12-21.05 12 21.05z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
pnpm_icon= Icon(
    title="pnpm",
    slug="pnpm",
    hex="F69220",
    source="https://pnpm.io/logos",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>pnpm</title><path d="M0 0v7.5h7.5V0zm8.25 0v7.5h7.498V0zm8.25 0v7.5H24V0zM8.25 8.25v7.5h7.498v-7.5zm8.25 0v7.5H24v-7.5zM0 16.5V24h7.5v-7.5zm8.25 0V24h7.498v-7.5zm8.25 0V24H24v-7.5z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
stitcher_icon= Icon(
    title="Stitcher",
    slug="stitcher",
    hex="000000",
    source="https://partners.stitcher.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Stitcher</title><path d="M19.59 8.516H24v6.928h-4.41zM0 8.854h4.41v7.803H0zm4.914-1.328h4.388v8.572H4.914zm4.892.725h4.388v8.81H9.806zm4.892-1.312h4.388v9.158h-4.388Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
unsplash_icon= Icon(
    title="Unsplash",
    slug="unsplash",
    hex="000000",
    source="https://unsplash.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Unsplash</title><path d="M7.5 6.75V0h9v6.75h-9zm9 3.75H24V24H0V10.5h7.5v6.75h9V10.5z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
azuredevops_icon= Icon(
    title="Azure DevOps",
    slug="azuredevops",
    hex="0078D7",
    source="http://azure.com/devops",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Azure DevOps</title><path d="M0 8.877L2.247 5.91l8.405-3.416V.022l7.37 5.393L2.966 8.338v8.225L0 15.707zm24-4.45v14.651l-5.753 4.9-9.303-3.057v3.056l-5.978-7.416 15.057 1.798V5.415z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
tvtime_icon= Icon(
    title="TV Time",
    slug="tvtime",
    hex="FFD400",
    source="https://www.tvtime.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>TV Time</title><path d="M0 0v24h24V0zm4.8 4.8h14.4v4.8h-4.8v9.6H9.6V9.6H4.8Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
monster_icon= Icon(
    title="Monster",
    slug="monster",
    hex="6D4C9F",
    source="https://www.monster.com/press/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Monster</title><path d="M0 0V24H5.42V12.39L12 18.19L18.58 12.39V24H24V0L12 11.23L0 0Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
simpleanalytics_icon= Icon(
    title="Simple Analytics",
    slug="simpleanalytics",
    hex="FF4F64",
    source="https://simpleanalytics.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Simple Analytics</title><path d="M1.019 13.019h3.849V24h-3.85zm8.943-6.68h3.85V24h-3.85zM19.132 0h3.85v24h-3.85z"/></svg>""",
    guidelines='https://simpleanalytics.com/press',
    license=None,
)



from simpleicons.icon import Icon
playcanvas_icon= Icon(
    title="PlayCanvas",
    slug="playcanvas",
    hex="E05F2C",
    source="https://playcanvas.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>PlayCanvas</title><path d="M6.115 0l-.002 3.414 5.823 3.41-5.82 3.414-.003 3.412 11.774-6.826zm11.77 10.35L6.113 17.174 17.887 24l-.002-3.414-5.82-3.412 5.822-3.412z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
virustotal_icon= Icon(
    title="VirusTotal",
    slug="virustotal",
    hex="394EFF",
    source="https://www.virustotal.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>VirusTotal</title><path d="M10.87 12L0 22.68h24V1.32H0zm10.73 8.52H5.28l8.637-8.448L5.28 3.48H21.6z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
expertsexchange_icon= Icon(
    title="Experts Exchange",
    slug="expertsexchange",
    hex="00AAE7",
    source="https://www.experts-exchange.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Experts Exchange</title><path d="M7.28.9H0L8.36 12 0 23.1h7.28L15.64 12zM24 .9h-7.28l-2.3 3.06 3.64 4.82zM14.42 20.05l2.3 3.05H24l-5.94-7.88z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
alitalia_icon= Icon(
    title="Alitalia",
    slug="alitalia",
    hex="006643",
    source="https://www.alitalia.com/it_it/fly-alitalia/in-flight/ulisse-magazine.html",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Alitalia</title><path d="M5.429 20.551H0l14.257-14.87c1.622-1.765 2.878-2.232 4.686-2.232H24L21.602 20.55h-4.17L19.49 5.907M15.7 20.551l1.384-9.842-9.457 9.842Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
serverless_icon= Icon(
    title="Serverless",
    slug="serverless",
    hex="FD5750",
    source="https://serverless.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Serverless</title><path d="M0 17.57h4.248l-1.316 3.974H0zm0-7.557h6.75l-1.316 3.974H0zm0-7.557h9.252L7.936 6.431H0zm13.44 0H24v3.975H12.123zM9.62 13.987l1.317-3.974H24v3.974zM8.436 17.57H24v3.975H7.119Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
xilinx_icon= Icon(
    title="Xilinx",
    slug="xilinx",
    hex="E01F27",
    source="https://www.xilinx.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Xilinx</title><path d="M8 18l5.241 6H5.586L.345 18l5.241-6L.345 6l5.241-6h7.655L8 6l5.241 6L8 18zM23.655 0H13.241l5.241 6 5.173-6zM13.241 24h10.414l-5.172-6-5.242 6z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
kibana_icon= Icon(
    title="Kibana",
    slug="kibana",
    hex="005571",
    source="https://www.elastic.co/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Kibana</title><path d="M2.625 0v21.591L21.375 0zm10.864 12.47L3.477 24h17.522a18.755 18.755 0 0 0-7.51-11.53z"/></svg>""",
    guidelines=None,
    license=None,
)



from typing import TypedDict
import re
from xml.etree import ElementTree as ET

ET.register_namespace("", "http://www.w3.org/2000/svg")


class License(TypedDict):
    """License information for each icon."""

    type: str
    url: str


class Icon:
    """An icon with all relevant data and methods."""

    def __init__(
        self,
        title: str,
        slug: str,
        hex: str,
        source: str,
        svg: str,
        guidelines: str,
        license: License,
    ):
        self.title = title
        self.slug = slug
        self.hex = hex
        self.source = source
        self.svg = svg
        self.guidelines = guidelines
        self.license = license

    @property
    def path(self):
        return re.findall(r'<path\s+d="([^"]*)', self.svg)[0]

    def get_element(self):
        """Get svg's element (parsed XML)."""

        return ET.fromstring(self.svg)

    def get_xml(self, **attrs):
        """Add attributes to the svg element.

        Args:
            **attrs: The attributes to add to the svg element.
        """

        svg = self.get_element()
        for attrName, attrValue in attrs.items():
            svg.set(attrName, attrValue)

        return svg

    def get_xml_bytes(self, **attrs):
        """Get the bytes for the svg's element tree."""

        return ET.tostring(self.get_xml(**attrs))



from simpleicons.icon import Icon
datocms_icon= Icon(
    title="DatoCMS",
    slug="datocms",
    hex="FF7751",
    source="https://www.datocms.com/company/brand-assets",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>DatoCMS</title><path d="M12 0H.076v24H12c5.964 0 11.924-5.373 11.924-11.998C23.924 5.376 17.963 0 12 0zm0 17.453a5.453 5.453 0 115.455-5.451A5.45 5.45 0 0112 17.452z"/></svg>""",
    guidelines='https://www.datocms.com/company/brand-assets',
    license=None,
)



from simpleicons.icon import Icon
spreadshirt_icon= Icon(
    title="Spreadshirt",
    slug="spreadshirt",
    hex="00B2A5",
    source="https://www.spreadshirt.ie/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Spreadshirt</title><path d="M12 6.306L7.796 2.102 0 9.898l12 12 12-12-7.796-7.796zm0 12L3.592 9.898l4.204-4.204L12 9.898l4.184-4.184 4.204 4.204"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
pleroma_icon= Icon(
    title="Pleroma",
    slug="pleroma",
    hex="FBA457",
    source="https://pleroma.social/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pleroma</title><path d="M6.36 0A1.868 1.868 0 004.49 1.868V24h5.964V0zm7.113 0v12h4.168a1.868 1.868 0 001.868-1.868V0zm0 18.036V24h4.168a1.868 1.868 0 001.868-1.868v-4.096Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
airfrance_icon= Icon(
    title="Air France",
    slug="airfrance",
    hex="002157",
    source="https://www.airfrance.fr/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Air France</title><path d="M13.776 3.9L5.184 16.332C4.051 17.969 2.208 19.548 0 19.721v.379h9.552c2.544 0 4.397-1.656 5.616-3.48L24 3.9Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
codeclimate_icon= Icon(
    title="Code Climate",
    slug="codeclimate",
    hex="000000",
    source="https://codeclimate.com/github/codeclimate/python-test-reporter/badges/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Code Climate</title><path d="M16.125 5.272l-4.511 4.475 2.684 2.659 1.827-1.813 5.19 5.145L24 13.079zM8.13 8.265L0 16.066l2.772 2.662 5.357-5.145 5.357 5.145 2.772-2.662z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
googlescholar_icon= Icon(
    title="Google Scholar",
    slug="googlescholar",
    hex="4285F4",
    source="https://commons.wikimedia.org/wiki/File:Google_Scholar_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Google Scholar</title><path d="M5.242 13.769L0 9.5 12 0l12 9.5-5.242 4.269C17.548 11.249 14.978 9.5 12 9.5c-2.977 0-5.548 1.748-6.758 4.269zM12 10a7 7 0 1 0 0 14 7 7 0 0 0 0-14z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
opencontainersinitiative_icon= Icon(
    title="Open Containers Initiative",
    slug="opencontainersinitiative",
    hex="262261",
    source="https://github.com/opencontainers/artwork/tree/master/oci/icon",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Open Containers Initiative</title><path d="M0 0v24h24V0zm20.547 20.431H3.448V3.573h17.104V20.43zm-5.155-9.979h3.436v8.255h-3.436zm0-5.16h3.436v3.436h-3.436zm-6.789 9.976V8.732h5.074v-3.44H5.164v13.415h8.513v-3.44Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
linuxfoundation_icon= Icon(
    title="Linux Foundation",
    slug="linuxfoundation",
    hex="003366",
    source="https://www.linuxfoundation.org/en/about/brand/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Linux Foundation</title><path d="M4.8 19.2h9.6V24H0V9.6h4.8v9.6zM0 0v7.2h4.8V4.822h14.4V19.2h-2.4V24H24V0H0z"/></svg>""",
    guidelines='https://www.linuxfoundation.org/en/about/brand/',
    license=None,
)



from simpleicons.icon import Icon
snapcraft_icon= Icon(
    title="Snapcraft",
    slug="snapcraft",
    hex="82BEA0",
    source="https://github.com/snapcore/snap-store-badges",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Snapcraft</title><path d="M13.804 13.367V5.69l5.292 2.362-5.292 5.315zM3.701 23.514l6.49-12.22 2.847 2.843L3.7 23.514zM0 .486l13.355 4.848v8.484L0 .486zM21.803 5.334H14.11L24 9.748z"/></svg>""",
    guidelines=None,
    license={'type': 'CC-BY-ND-2.0', 'url': 'https://spdx.org/licenses/CC-BY-ND-2.0'},
)



from simpleicons.icon import Icon
osano_icon= Icon(
    title="Osano",
    slug="osano",
    hex="7764FA",
    source="https://www.osano.com/company/assets",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Osano</title><path d="M12 6.091A5.909 5.909 0 1017.909 12 5.91 5.91 0 0012 6.091M12 0A12 12 0 110 12 12 12 0 0112 0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
roblox_icon= Icon(
    title="Roblox",
    slug="roblox",
    hex="000000",
    source="https://corp.roblox.com/press-kit/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Roblox</title><path d="m13.383 14.341-3.726-.958.959-3.726 3.726.959-.96 3.726zM4.913 0 0 19.088 19.088 24 24 4.912 4.912 0z"/></svg>""",
    guidelines='https://corp.roblox.com/wp-content/uploads/2021/03/Logo_Roblox.zip',
    license=None,
)



from simpleicons.icon import Icon
logstash_icon= Icon(
    title="Logstash",
    slug="logstash",
    hex="005571",
    source="https://www.elastic.co/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Logstash</title><path d="M13.745 24h8.291v-9.164h-8.29zm-2.618 0h.437v-9.164h-9.6A9.163 9.163 0 0011.127 24m.438-9.164h-9.6V0h.873a8.727 8.727 0 018.727 8.727z"/></svg>""",
    guidelines='https://www.elastic.co/brand',
    license=None,
)



from simpleicons.icon import Icon
patreon_icon= Icon(
    title="Patreon",
    slug="patreon",
    hex="FF424D",
    source="https://www.patreon.com/brand/downloads",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Patreon</title><path d="M0 .48v23.04h4.22V.48zm15.385 0c-4.764 0-8.641 3.88-8.641 8.65 0 4.755 3.877 8.623 8.641 8.623 4.75 0 8.615-3.868 8.615-8.623C24 4.36 20.136.48 15.385.48z"/></svg>""",
    guidelines='https://www.patreon.com/brand/downloads',
    license=None,
)



from simpleicons.icon import Icon
tensorflow_icon= Icon(
    title="TensorFlow",
    slug="tensorflow",
    hex="FF6F00",
    source="https://www.tensorflow.org/extras/tensorflow_brand_guidelines.pdf",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>TensorFlow</title><path d="M1.292 5.856L11.54 0v24l-4.095-2.378V7.603l-6.168 3.564.015-5.31zm21.43 5.311l-.014-5.31L12.46 0v24l4.095-2.378V14.87l3.092 1.788-.018-4.618-3.074-1.756V7.603l6.168 3.564z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
xdadevelopers_icon= Icon(
    title="XDA Developers",
    slug="xdadevelopers",
    hex="EA7100",
    source="https://www.xda-developers.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>XDA Developers</title><path d="M13.84 3.052V0h7.843v17.583H13.84v-3.024h4.591V3.052zM5.569 14.53V3.024h4.592V0H2.318v17.583H6.98L10.16 24v-9.483z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
rubygems_icon= Icon(
    title="RubyGems",
    slug="rubygems",
    hex="E9573F",
    source="https://rubygems.org/pages/about",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>RubyGems</title><path d="M7.81 7.9l-2.97 2.95 7.19 7.18 2.96-2.95 4.22-4.23-2.96-2.96v-.01H7.8zM12 0L1.53 6v12L12 24l10.47-6V6L12 0zm8.47 16.85L12 21.73l-8.47-4.88V7.12L12 2.24l8.47 4.88v9.73z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
lospec_icon= Icon(
    title="Lospec",
    slug="lospec",
    hex="EAEAEA",
    source="https://lospec.com/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Lospec</title><path d="M4.23 0v24h15.541v-8.4004h-7.1719v3.5996H11.402V0z"/></svg>""",
    guidelines='https://lospec.com/brand',
    license=None,
)



from simpleicons.icon import Icon
terraform_icon= Icon(
    title="Terraform",
    slug="terraform",
    hex="7B42BC",
    source="https://www.hashicorp.com/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Terraform</title><path d="M1.44 0v7.575l6.561 3.79V3.787zm21.12 4.227l-6.561 3.791v7.574l6.56-3.787zM8.72 4.23v7.575l6.561 3.787V8.018zm0 8.405v7.575L15.28 24v-7.578z"/></svg>""",
    guidelines='https://www.hashicorp.com/brand',
    license=None,
)



from simpleicons.icon import Icon
kotlin_icon= Icon(
    title="Kotlin",
    slug="kotlin",
    hex="0095D5",
    source="https://resources.jetbrains.com/storage/products/kotlin/docs/kotlin_logos.zip",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Kotlin</title><path d="M0 24V13.848L13.505 0H24L0 24zM0 0v12.672L12.05 0H0zm1.335 24H24L12.699 12.618 1.335 24z"/></svg>""",
    guidelines='https://www.jetbrains.com/company/brand/',
    license=None,
)



from simpleicons.icon import Icon
hyper_icon= Icon(
    title="Hyper",
    slug="hyper",
    hex="000000",
    source="https://hyper.is/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Hyper</title><path d="M13.565 17.91H24v1.964H13.565zm-3.201-5.09l-9.187 8.003 2.86-7.004L0 11.179l9.187-8.002-3.11 7.451z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
informatica_icon= Icon(
    title="Informatica",
    slug="informatica",
    hex="FF4D00",
    source="https://www.informatica.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Informatica</title><path d="M12 0l3.547 10.788-4.5-1.255-.25 4.43 7.121 4.035V18h.001l5.919-6zm-.64.65L.162 12l6.32 6.407L12 24l5.184-5.255-9.736-3.856z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
nintendo_icon= Icon(
    title="Nintendo",
    slug="nintendo",
    hex="8F8F8F",
    source="https://en.wikipedia.org/wiki/Nintendo#/media/File:Nintendo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Nintendo</title><path d="M0 .6h7.1l9.85 15.9V.6H24v22.8h-7.04L7.06 7.5v15.9H0V.6"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
awsamplify_icon= Icon(
    title="AWS Amplify",
    slug="awsamplify",
    hex="FF9900",
    source="https://docs.amplify.aws/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>AWS Amplify</title><path d="M5.223 17.905h6.76l1.731 3.047H0l4.815-8.344 2.018-3.494 1.733 3.002zm2.52-10.371L9.408 4.65l9.415 16.301h-3.334zm2.59-4.486h3.33L24 20.952h-3.334z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
windows_icon= Icon(
    title="Windows",
    slug="windows",
    hex="0078D6",
    source="https://commons.wikimedia.org/wiki/File:Windows_10_Logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Windows</title><path d="M0 3.449L9.75 2.1v9.451H0m10.949-9.602L24 0v11.4H10.949M0 12.6h9.75v9.451L0 20.699M10.949 12.6H24V24l-12.9-1.801"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
netapp_icon= Icon(
    title="NetApp",
    slug="netapp",
    hex="0067C5",
    source="http://www.netapp.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>NetApp</title><path d="M0 2v20h9.33V10h5.34v12H24V2Z"/></svg>""",
    guidelines='https://www.netapp.com/company/legal/trademark-guidelines/',
    license=None,
)



from simpleicons.icon import Icon
telegraph_icon= Icon(
    title="Telegraph",
    slug="telegraph",
    hex="FAFAFA",
    source="https://telegra.ph/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Telegraph</title><path d="M0 0v24h24V0H0zm6 6h12v3h-4.5v9h-3V9H6V6Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
deutschebank_icon= Icon(
    title="Deutsche Bank",
    slug="deutschebank",
    hex="0018A8",
    source="https://www.db.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Deutsche Bank</title><path d="M3.375 3.375v17.25h17.25V3.375H3.375zM0 0h24v24H0V0zm5.25 18.225 9.15-12.45h4.35L9.6 18.225H5.25z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
anydesk_icon= Icon(
    title="AnyDesk",
    slug="anydesk",
    hex="EF443B",
    source="https://anydesk.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>AnyDesk</title><path d="M8.322 3.677L0 12l8.322 8.323L16.645 12zm7.371.01l-1.849 1.85 6.49 6.456-6.49 6.49 1.85 1.817L24 11.993Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
goldenline_icon= Icon(
    title="GoldenLine",
    slug="goldenline",
    hex="FFE005",
    source="http://www.goldenline.pl",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>GoldenLine</title><path d="M11.997 24a11.995 11.995 0 0 0 11.949-13.04h-6.781v2.943h1.226a6.667 6.667 0 1 1-.114-4.156h5.509A11.995 11.995 0 1 0 12 23.991z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
delicious_icon= Icon(
    title="del.icio.us",
    slug="delicious",
    hex="0000FF",
    source="http://del.icio.us/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>del.icio.us</title><path d="M12 12H0v12h12V12zM24 0H12v12h12V0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
ethereum_icon= Icon(
    title="Ethereum",
    slug="ethereum",
    hex="3C3C3D",
    source="https://ethereum.org/en/assets/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Ethereum</title><path d="M11.944 17.97L4.58 13.62 11.943 24l7.37-10.38-7.372 4.35h.003zM12.056 0L4.69 12.223l7.365 4.354 7.365-4.35L12.056 0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
aerospike_icon= Icon(
    title="Aerospike",
    slug="aerospike",
    hex="C41E25",
    source="http://pages.aerospike.com/rs/aerospike/images/Acid_Whitepaper.pdf",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Aerospike</title><path d="M0 0v24h24V0zm19.295 5.386v1.64l-3.576 1.586v7.363l3.576 1.602v1.565L5.672 12.98l-1.607-.688 1.607-.743zm-4.948 3.825L7.45 12.283l6.897 3.092Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
googledrive_icon= Icon(
    title="Google Drive",
    slug="googledrive",
    hex="4285F4",
    source="https://developers.google.com/drive/web/branding",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Google Drive</title><path d="M4.433 22.396l4-6.929H24l-4 6.929H4.433zm3.566-6.929l-3.998 6.929L0 15.467 7.785 1.98l3.999 6.931-3.785 6.556zm15.784-.375h-7.999L7.999 1.605h8.002l7.785 13.486h-.003z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
microsoft_icon= Icon(
    title="Microsoft",
    slug="microsoft",
    hex="5E5E5E",
    source="https://developer.microsoft.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Microsoft</title><path d="M0 0v11.408h11.408V0zm12.594 0v11.408H24V0zM0 12.594V24h11.408V12.594zm12.594 0V24H24V12.594z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
dynamics365_icon= Icon(
    title="Dynamics 365",
    slug="dynamics365",
    hex="002050",
    source="http://thepartnerchannel.com/wp-content/uploads/Dynamics365_styleguide_092816.pdf",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Dynamics 365</title><path d="M4.59 7.41l4.94 3.54L4.59 24zm0-7.41v6.36l9.53 5.29 4.59-3.52zm0 24l14.82-8.47v-6.7Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
aframe_icon= Icon(
    title="A-Frame",
    slug="aframe",
    hex="EF2D5E",
    source="https://aframe.io/docs/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>A-Frame</title><path d="M17.37 17.07H6.57L4.24 24H3.01l8.23-24h1.52l8.23 24h-1.3zm-.39-1.13l-5-14.96-5.03 14.98h10.03Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
hurriyetemlak_icon= Icon(
    title="Hurriyetemlak",
    slug="hurriyetemlak",
    hex="E02826",
    source="https://ilan.hurriyetemlak.com/emlak-ilani-yayinlama-kurallari",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Hurriyetemlak</title><path d="M24 16.085L11.994 4.091 0 16.097l3.817 3.812 8.182-8.189 8.189 8.182z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
bookmeter_icon= Icon(
    title="Bookmeter",
    slug="bookmeter",
    hex="64BC4B",
    source="https://bookmeter.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bookmeter</title><path d="M.678 14.262h6.089V24H.678v-9.738zm8.215 9.717h6.089V7.11H8.893v16.869zM17.234 0v24h6.089V0h-6.089z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
mitsubishi_icon= Icon(
    title="Mitsubishi",
    slug="mitsubishi",
    hex="E60012",
    source="https://www.mitsubishi.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Mitsubishi</title><path d="M8 22.38H0l4-6.92h8zm8 0h8l-4-6.92h-8zm0-13.84l-4-6.92-4 6.92 4 6.92Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
prosieben_icon= Icon(
    title="ProSieben",
    slug="prosieben",
    hex="E6000F",
    source="https://www.prosieben.de/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>ProSieben</title><path d="M.24 0H23.68V6.64H.24M23.76 7.92V24H.24s2.88-7.84 10.48-12.48c7.12-4.4 13.04-3.6 13.04-3.6Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
feathub_icon= Icon(
    title="FeatHub",
    slug="feathub",
    hex="9B9B9B",
    source="http://feathub.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>FeatHub</title><path d="M8.571 0v6.857h6.858V0zM0 8.571v6.858h24V8.57zm8.571 8.572V24h6.858v-6.857z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
docusign_icon= Icon(
    title="DocuSign",
    slug="docusign",
    hex="FFCC22",
    source="https://github.com/simple-icons/simple-icons/issues/1098",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>DocuSign</title><path d="M9.517 3.31h4.966v6.621h3.31L12 16.552 6.207 9.931h3.31V3.31zM0 19.034h24v1.655H0v-1.655z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
vuedotjs_icon= Icon(
    title="Vue.js",
    slug="vuedotjs",
    hex="4FC08D",
    source="https://github.com/vuejs/art",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vue.js</title><path d="M24,1.61H14.06L12,5.16,9.94,1.61H0L12,22.39ZM12,14.08,5.16,2.23H9.59L12,6.41l2.41-4.18h4.43Z"/></svg>""",
    guidelines='https://github.com/vuejs/art/blob/master/README.md',
    license={'type': 'custom', 'url': 'https://github.com/vuejs/art/blob/master/README.md'},
)



from simpleicons.icon import Icon
supabase_icon= Icon(
    title="Supabase",
    slug="supabase",
    hex="3ECF8E",
    source="https://github.com/supabase/supabase/blob/2a983c3290148d17cfce9e34c0a39102b22fdf78/web/static/img/showcase-logo/supabase-logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Supabase</title><path d="M21.362 9.354H12V.396a.396.396 0 0 0-.716-.233L2.203 12.424l-.401.562a1.04 1.04 0 0 0 .836 1.659H12v8.959a.396.396 0 0 0 .716.233l9.081-12.261.401-.562a1.04 1.04 0 0 0-.836-1.66z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
lit_icon= Icon(
    title="Lit",
    slug="lit",
    hex="324FFF",
    source="https://github.com/lit/lit.dev/blob/5e59bdb00b7a261d6fdcd6a4ae529e17f6146ed3/packages/lit-dev-content/site/images/flame-favicon.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Lit</title><path d="M2.4 9.6l4.8 4.8V24l-4.8-4.8V9.6zm4.8-4.8v9.6L12 9.6V0L7.2 4.8zM12 9.6v9.6l4.8-4.8V4.8L12 9.6zm4.8 4.8V24l4.8-4.8V9.6l-4.8 4.8z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
razorpay_icon= Icon(
    title="Razorpay",
    slug="razorpay",
    hex="0C2451",
    source="https://razorpay.com/newsroom/brand-assets/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Razorpay</title><path d="M22.436 0l-11.91 7.773-1.174 4.276 6.625-4.297L11.65 24h4.391l6.395-24zM14.26 10.098L3.389 17.166 1.564 24h9.008l3.688-13.902Z"/></svg>""",
    guidelines='https://razorpay.com/newsroom/brand-assets/',
    license=None,
)



from simpleicons.icon import Icon
bbciplayer_icon= Icon(
    title="BBC iPlayer",
    slug="bbciplayer",
    hex="F54997",
    source="https://www.bbc.co.uk/iplayer",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>BBC iPlayer</title><path d="M8.315 0H2.382v6.022h5.933V3.506l9.618 8.45-9.618 8.538V8.99H2.382V24h5.933l13.303-12.045Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
lighthouse_icon= Icon(
    title="Lighthouse",
    slug="lighthouse",
    hex="F44B21",
    source="https://github.com/GoogleChrome/lighthouse/blob/80d2e6c1948f232ec4f1bdeabc8bc632fc5d0bfd/assets/lh_favicon.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Lighthouse</title><path d="M12 0l5.5 3.5v5H20v3h-2.25l2 12.5H4.25l2-12.5H4v-3h2.5V3.53zm2.94 13.25l-6.22 2.26L8 20.04l7.5-2.75zM12 3.56L9.5 5.17V8.5h5V5.15Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
bulma_icon= Icon(
    title="Bulma",
    slug="bulma",
    hex="00D1B2",
    source="https://github.com/jgthms/bulma/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bulma</title><path d="M11.25 0l-6 6 -1.5 10.5 7.5 7.5 9 -6 -6 -6 4.5 -4.5 -7.5 -7.5Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
palantir_icon= Icon(
    title="Palantir",
    slug="palantir",
    hex="101113",
    source="https://github.com/palantir/conjure/blob/master/docs/media/palantir-logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Palantir</title><path d="M20.147 18L12 21.178 3.853 18 2.5 20.343 12 24l9.5-3.657L20.147 18zM12 0a9.5 9.5 0 1 0 0 19 9.5 9.5 0 0 0 0-19zm0 16.078a6.568 6.568 0 1 1 0-13.136 6.568 6.568 0 0 1 0 13.136z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
jamboard_icon= Icon(
    title="Jamboard",
    slug="jamboard",
    hex="F37C20",
    source="https://cdn2.hubspot.net/hubfs/159104/ECS/Jamboard/Approved%20Jamboard%20Brand%20Book.pdf",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Jamboard</title><path d="M12.143 0v7.877h7.783V0zm0 8.155v7.784h7.783V8.155zm-.28.005a7.926 7.923 0 0 0-7.789 7.917A7.926 7.923 0 0 0 12 24a7.926 7.923 0 0 0 7.918-7.78h-8.056Z"/></svg>""",
    guidelines='https://cdn2.hubspot.net/hubfs/159104/ECS/Jamboard/Approved%20Jamboard%20Brand%20Book.pdf',
    license=None,
)



from simpleicons.icon import Icon
eclipseche_icon= Icon(
    title="Eclipse Che",
    slug="eclipseche",
    hex="525C86",
    source="https://www.eclipse.org/che/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Eclipse Che</title><path d="M12 0L1.604 6.021v7.452L12 7.494l3.941 2.254 6.455-3.727zm10.396 10.527L12 16.506l-7.334-4.217-3.062 1.76v3.93L12 24l10.396-6.021z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
beats_icon= Icon(
    title="Beats",
    slug="beats",
    hex="005571",
    source="https://www.elastic.co/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Beats</title><path d="M2.625 0v15h8.25a7.5 7.5 0 0 0 0-15zm17.016 11.705c-1.571 3.261-4.91 5.517-8.766 5.517h-8.25V24h11.25a7.5 7.5 0 0 0 5.766-12.295z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
bandcamp_icon= Icon(
    title="Bandcamp",
    slug="bandcamp",
    hex="408294",
    source="https://bandcamp.com/buttons",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Bandcamp</title><path d="M0 18.75l7.437-13.5H24l-7.438 13.5H0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
squareenix_icon= Icon(
    title="Square Enix",
    slug="squareenix",
    hex="ED1C24",
    source="https://www.square-enix.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Square Enix</title><path d="M1.723 0v24h20.554v-4.496H7.037V4.088h15.006V0zm9.751 9.46v4.497h8.584V9.459z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
adonisjs_icon= Icon(
    title="AdonisJS",
    slug="adonisjs",
    hex="220052",
    source="https://adonisjs.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>AdonisJS</title><path d="M13.333 1.333l-.596 1.193-2.404 4.807L8 2.667l-8 16h4.667l-2 4H24zm0 2.982l8.51 17.018H4.823l1.334-2.666H16l-4.922-9.843Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
framer_icon= Icon(
    title="Framer",
    slug="framer",
    hex="0055FF",
    source="https://framer.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Framer</title><path d="M4 0h16v8h-8zM4 8h8l8 8H4zM4 16h8v8z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
radar_icon= Icon(
    title="Radar",
    slug="radar",
    hex="007AFF",
    source="https://radar.io/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Radar</title><path d="M12 0L2.197 23.975 12 19.952 21.803 24z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
reverbnation_icon= Icon(
    title="ReverbNation",
    slug="reverbnation",
    hex="E43526",
    source="https://www.reverbnation.com",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>ReverbNation</title><path d="M24 9.324l-9.143-.03L11.971.57 9.143 9.294 0 9.324h.031l7.367 5.355-2.855 8.749h.029l7.459-5.386 7.396 5.386-2.855-8.73L24 9.315"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
houzz_icon= Icon(
    title="Houzz",
    slug="houzz",
    hex="4DBC15",
    source="https://www.houzz.com/logoGuidelines",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Houzz</title><path d="M1.27 0V24H9.32V16.44H14.68V24H22.73V10.37L6.61 5.75V0H1.27Z"/></svg>""",
    guidelines='https://www.houzz.com/logoGuidelines',
    license=None,
)



from simpleicons.icon import Icon
xstate_icon= Icon(
    title="XState",
    slug="xstate",
    hex="2C3E50",
    source="https://github.com/davidkpiano/xstate/blob/544df7f00e2ef49603b5e5ff2f0d183ff6bd5e7c/docs/.vuepress/public/logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>XState</title><path d="M15.891 0h6.023l-6.085 10.563c-1.853-3.305-1.822-7.32.062-10.563zm6.055 23.999L8.078.001H2.055l6.919 12.015L2.055 24h6.023L12 17.236 15.892 24z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
koding_icon= Icon(
    title="Koding",
    slug="koding",
    hex="00B057",
    source="https://koding.com/About",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Koding</title><path d="M.8 0H23v6H1V0zm0 9H18v6H.7V9zm0 9H23v6H1v-6z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
vectorlogozone_icon= Icon(
    title="Vector Logo Zone",
    slug="vectorlogozone",
    hex="184D66",
    source="https://www.vectorlogo.zone/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vector Logo Zone</title><path d="M19.458 0l-5.311 2.024 1.989.534-4.847 16.085-4.867-16.25H1.48L8.974 24h4.645l7.043-20.226 1.858.499Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
giphy_icon= Icon(
    title="GIPHY",
    slug="giphy",
    hex="FF6666",
    source="https://support.giphy.com/hc/en-us/articles/360022283772-GIPHY-Brand-Guidelines",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>GIPHY</title><path d="M2.666 0v24h18.668V8.666l-2.668 2.668v10H5.334V2.668H10L12.666 0zm10.668 0v8h8V5.334h-2.668V2.668H16V0"/></svg>""",
    guidelines='https://support.giphy.com/hc/en-us/articles/360022283772-GIPHY-Brand-Guidelines',
    license=None,
)



from simpleicons.icon import Icon
vuetify_icon= Icon(
    title="Vuetify",
    slug="vuetify",
    hex="1867C0",
    source="https://vuetifyjs.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Vuetify</title><path d="M7.094 0L12 11.596 16.906 0H7.094zM1.5 3.5L12 24 22.5 3.5H17L12 15 7 3.5z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
plex_icon= Icon(
    title="Plex",
    slug="plex",
    hex="E5A00D",
    source="https://brand.plex.tv/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Plex</title><path d="M11.643 0H4.68l7.679 12L4.68 24h6.963l7.677-12-7.677-12"/></svg>""",
    guidelines='https://brand.plex.tv/',
    license=None,
)



from simpleicons.icon import Icon
zotero_icon= Icon(
    title="Zotero",
    slug="zotero",
    hex="CC2936",
    source="https://www.zotero.org/support/brand",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Zotero</title><path d="M21.231 2.462 7.18 20.923h14.564V24H2.256v-2.462L16.308 3.076H2.975V0h18.256v2.462z"/></svg>""",
    guidelines=None,
    license=None,
)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['simpleicons', 'simpleicons.icons']

package_data = \
{'': ['*']}

extras_require = \
{'auto-update': ['semantic-version>=2.8.5,<3.0.0',
                 'requests>=2.25.1,<3.0.0',
                 'GitPython>=3.1.18,<4.0.0'],
 'imaging': ['reportlab>=3.5.68,<4.0.0',
             'Pillow>=8.3.1,<9.0.0',
             'svglib>=1.1.0,<2.0.0']}

setup_kwargs = {
    'name': 'simpleicons',
    'version': '5.13.0',
    'description': 'Use a wide-range of icons derived from the simple-icons/simple-icons repo in python.',
    'long_description': '<h1>\n  <img src="logo.svg" alt="Logo" width="50" height="50">\n  simpleicons\n</h1>\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n\nUse a wide-range of icons derived from the [simple-icons](https://github.com/simple-icons/simple-icons) repo in python. Go to [their website](https://simpleicons.org/) for a full list of icons. The slug version must be used for the `icon_name`. The icons folder that accompanies the package has all the files. The package uses the latest verison of [Simple Icons](https://github.com/simple-icons/simple-icons/releases/latest). It does **not** depend on the filesystem.\n\n## Installation\n\nInstall with `pip install simpleicons`. Keep in mind that this is a fairly large package due to all the icons.\n\n## Usage\n\n### General Usage\n\nThe API can then be used as follows, where [ICON SLUG] is replaced by a slug:\n\n```py\nfrom simpleicons.all import icons\n\n# Get a specific icon by its slug as:\nicons.get(\'[ICON SLUG]\')\n\n# For example:\nicon = icons.get(\'simpleicons\')\n\nprint(icon.__dict__)\n\n"""\n{\n    \'title\': \'Simple Icons\',\n    \'slug\': \'simpleicons\',\n    \'hex\': \'111111\',\n    \'source\': \'https://simpleicons.org/\',\n    \'svg\': \'<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">...</svg>\',\n    \'path\': \'M12 12v-1.5c-2.484 ...\',\n    \'guidelines\': \'https://simpleicons.org/styleguide\',\n    \'license\': {\n        type: \'...\',\n        url: \'https://example.com/\'\n    }\n}\n"""\n```\n\nNOTE: The `guidelines` entry will be `None` if we do not yet have guidelines data for the icon.\n\nNOTE: The `license` entry will be `None` if we do not yet have license data for the icon.\n\nAlternatively you can import the needed icons individually, where [ICON SLUG] is replaced by a slug:\n\n```py\n# Import a specific icon by its slug as:\nfrom simpleicons.icons.[ICON SLUG] import [ICON_SLUG]_icon\n\n# For example:\nfrom simpleicons.icons.simpleicons import simpleicons_icon\n```\n\nLastly, the `icons` object is also enumerable. This is useful if you want to do a computation on every icon:\n\n```py\nfrom simpleicons.all import icons\n\nfor (key, icon in icons) {\n    # do stuff\n}\n```\n\n### XML\n\nThe XML for each icon can be easily manipulated with either of two functions:\n\n`Icon.get_xml(**attrs) -> ElementTree`\n\n```py\nfrom simpleicons.icons.simpleicons import simpleicons_icon\n\n# blue logo, adds the fill attribute: <svg fill="blue"></svg>\nsimpleicons_icon.get_xml(fill="blue")\n```\n\n`Icon.get_xml_bytes(**attrs) -> bytes`\n\n```py\nfrom simpleicons.icons.simpleicons import simpleicons_icon\n\nsimpleicons_icon.get_xml_bytes(fill="blue")\n```\n\n### Image\n\nIn order to use this, you must install the extras: `pip install -e simpleicons[imaging]` . Icons can be converted to PIL Images with `icon_to_image(icon_xml: bytes, bg: int=0xffffff, scale: Tuple[int, int]=(1, 1)) -> Image`:\n\n```py\nfrom simpleicons.icons.simpleicons import simpleicons_icon\nfrom simpleicons.image import icon_to_image\n\nxml_bytes = simpleicons_icon.get_xml_bytes(fill="blue")\n\n# black background and 5x scale\nimg = icon_to_image(xml_bytes, bg=0x000000, scale=(5, 5))\n\n# manipulate PIL Image\nimg.putalpha(32)\nimg.save("simpleicons_blue.png")\n```\n',
    'author': 'Sachin Raja',
    'author_email': 'sachinraja2349@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sachinraja/simpleicons',
    'packages': packages,
    'package_data': package_data,
    'extras_require': extras_require,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from simpleicons.icon import Icon
peertube_icon= Icon(
    title="PeerTube",
    slug="peertube",
    hex="F1680D",
    source="https://joinpeertube.org/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>PeerTube</title><path d="M12 6.545v10.91L20.727 12M3.273 12v12L12 17.455M3.273 0v12L12 6.545"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
teratail_icon= Icon(
    title="teratail",
    slug="teratail",
    hex="F4C51C",
    source="https://teratail.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>teratail</title><path d="M9.81.968h4.375L24 23.032h-5.107L12.121 6.605h-.198L5.148 23.03H0Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
betfair_icon= Icon(
    title="Betfair",
    slug="betfair",
    hex="FFB80B",
    source="https://partnerships.betfair.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Betfair</title><path d="M20.218 3.14h-7.083v3.6H9.352l7.359 8.582L24 6.67h-3.782zM0 17.26h3.782v3.6h7.083v-3.6h3.783l-7.29-8.583z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
transportforireland_icon= Icon(
    title="Transport for Ireland",
    slug="transportforireland",
    hex="00B274",
    source="https://www.transportforireland.ie/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Transport for Ireland</title><path d="M0 0v12c0 6.62 5.38 12 12 12h12V11.978h-.022c0-6.62-5.38-11.978-12-11.978zm3.376 8.145h6.337v1.546h-2.33v6.12H5.706v-6.12h-2.33zm8.014 0h5.837V9.67h-4.138v1.633h3.659v1.546h-3.659v2.962H11.39zm7.535 0h1.678v7.666h-1.678Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
adobe_icon= Icon(
    title="Adobe",
    slug="adobe",
    hex="FF0000",
    source="https://www.adobe.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Adobe</title><path d="M13.966 22.624l-1.69-4.281H8.122l3.892-9.144 5.662 13.425zM8.884 1.376H0v21.248zm15.116 0h-8.884L24 22.624Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
pagekit_icon= Icon(
    title="Pagekit",
    slug="pagekit",
    hex="212121",
    source="https://pagekit.com/logo-guide",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Pagekit</title><path d="M2.401 0v24h9.6v-3.527H5.929V3.526h12.146v13.421h-6.073v3.525H21.6V0H2.401z"/></svg>""",
    guidelines='https://pagekit.com/logo-guide',
    license=None,
)



from simpleicons.icon import Icon
undertale_icon= Icon(
    title="Undertale",
    slug="undertale",
    hex="E71D29",
    source="https://undertale.com/",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Undertale</title><path d="M3 0v1.5H1.5V3H0v12h3v3h3v3h3v3h6v-3h3v-3h3v-3h3V3h-1.5V1.5H21V0h-3v1.5h-3V3h-1.5v3h-3V3H9V1.5H6V0z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
vbulletin_icon= Icon(
    title="vBulletin",
    slug="vbulletin",
    hex="184D66",
    source="https://commons.wikimedia.org/wiki/File:VBulletin.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>vBulletin</title><path d="M1.09 10.316V24h21.82V0h-2.417l-5.461 19.613h-6.09l-3.134-9.246zm9.283-4.444l1.363 6.308L13.955 0H1.089v5.872Z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
spectrum_icon= Icon(
    title="Spectrum",
    slug="spectrum",
    hex="7B16FF",
    source="https://spectrum.chat",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Spectrum</title><path d="M0 10.2A1.8 1.8 0 001.8 12h1.8a8.4 8.4 0 018.4 8.4v1.8a1.8 1.8 0 001.8 1.8h8.4a1.8 1.8 0 001.8-1.8v-1.8C24 9.133 14.867 0 3.6 0H1.8A1.8 1.8 0 000 1.8v8.4z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
riseup_icon= Icon(
    title="Riseup",
    slug="riseup",
    hex="FF0000",
    source="https://riseup.net/en/about-us/images",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Riseup</title><path d="M10.5 24l-1.485-9.007-8.961-1.738L8.16 9.06 7.045 0l6.495 6.414 8.271-3.861-4.093 8.16 6.228 6.673-9.024-1.372z"/></svg>""",
    guidelines=None,
    license=None,
)



from simpleicons.icon import Icon
playstation2_icon= Icon(
    title="PlayStation 2",
    slug="playstation2",
    hex="003791",
    source="https://commons.wikimedia.org/wiki/File:PlayStation_2_logo.svg",
    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>PlayStation 2</title><path d="M7.46 13.779v.292h4.142v-3.85h3.796V9.93h-4.115v3.85zm16.248-3.558v1.62h-7.195v2.23H24v-.292h-7.168v-1.646H24V9.929h-7.487v.292zm-16.513 0v1.62H0v2.23h.292v-1.938H7.46V9.929H0v.292Z"/></svg>""",
    guidelines=None,
    license=None,
)
